summaryrefslogtreecommitdiffstats
path: root/toolkit/components/extensions/webidl-api/GenerateWebIDLBindings.py
diff options
context:
space:
mode:
Diffstat (limited to 'toolkit/components/extensions/webidl-api/GenerateWebIDLBindings.py')
-rw-r--r--toolkit/components/extensions/webidl-api/GenerateWebIDLBindings.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/toolkit/components/extensions/webidl-api/GenerateWebIDLBindings.py b/toolkit/components/extensions/webidl-api/GenerateWebIDLBindings.py
index 3b31bd924d..6a4a404ac8 100644
--- a/toolkit/components/extensions/webidl-api/GenerateWebIDLBindings.py
+++ b/toolkit/components/extensions/webidl-api/GenerateWebIDLBindings.py
@@ -139,8 +139,8 @@ def read_json(json_file_path):
"""
Helper function used to read the WebExtensions API schema JSON files
by ignoring the license comment on the top of some of those files.
- Same helper as the one available in Schemas.jsm:
- https://searchfox.org/mozilla-central/rev/3434a9df60373a997263107e6f124fb164ddebf2/toolkit/components/extensions/Schemas.jsm#70
+ Same helper as the one available in Schemas.sys.mjs:
+ https://searchfox.org/mozilla-central/rev/b60cb73160843adb5a5a3ec8058e75a69b46acf7/toolkit/components/extensions/Schemas.sys.mjs#53
"""
with open(json_file_path) as json_file:
txt = json_file.read()